@@ -1,5 +1,5 @@
 package Thrift::SASL::Transport;
-$Thrift::SASL::Transport::VERSION = '0.006';
+$Thrift::SASL::Transport::VERSION = '0.007';
 use strict;
 use warnings;
 use Data::Dumper;
@@ -33,11 +33,12 @@ use constant {
 };
 
 sub new {
-    my ( $class, $transport, $sasl, $debug ) = @_;
+    my ( $class, $transport, $sasl, $debug, $principal ) = @_;
     return bless {
         _transport => $transport,
         _sasl      => $sasl,
         _debug     => $debug || 0,
+        ($principal ? (_principal => $principal): ()),
     }, $class;
 }
 
@@ -89,7 +90,23 @@ sub _sasl_handshake {
 
     # The socket passed to BufferedTransport was put in that object's
     # "transport" property, this is a bit confusing imho
-    my $client = $self->{_sasl}->client_new( 'hive', $self->{_transport}{transport}{host} );
+    my $client;
+    if($self->{_sasl}->mechanism eq 'GSSAPI'){
+        if(!$self->{_principal}){
+            die "Principal needs to be specified for kerberos authentication."
+        }
+        my @kerberos_name_split = split('[/@]', $self->{_principal});
+        if(scalar @kerberos_name_split != 3){
+            die "Kerberos principal name should have 3 parts. Eg: hive/_HOST\@REALM.COM";
+        }
+        $client = $self->{_sasl}->client_new( $kerberos_name_split[0], $kerberos_name_split[1] );
+    }elsif($self->{_sasl}->mechanism eq 'DIGEST-MD5'){
+        # Server is configured with null and default for authentication with delegationtoken.
+        $client = $self->{_sasl}->client_new( 'null', 'default' );
+    }else{
+        #Keeping this line here for keep support for other mechanisms.
+        $client = $self->{_sasl}->client_new( 'hive', $self->{_transport}{transport}{host} );
+    }
     my $resp = $client->client_start();
 
     my $step;
@@ -264,7 +281,7 @@ Thrift::SASL::Transport - Thrift Transport allowing Kerberos auth/encryption thr
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
